function [adata,error]=rdaAUG_eff(shot,diagname,sigtype,varargin);
%
% gets data using SF2ML or mdsplus (when mdsplus will be available)
% 1D arrays: assumes dimension is time
% 2D arrays: assumes data vs (x,time)
% 3D arrays: assumes data vs (x,time,hsig) (for mdsplus)
%
% varargin{1}: time interval or timevalue, will get data closest to that time or within that time interval
%
% examples:
%          [data,error]=rdaAUG_eff(15133,'MAG','Ipi');
%          [data,error]=rdaAUG_eff(15133,'MAG','Ipi',[1 5]);
%
% set global variable: usemdsplus to decide if SF2ML or mdsplus is used:
%    >> global usemdsplus
%    >> usemdsplus=1 % means use mds to get data
%    >> usemdsplus=0 % means use SF2ML  (default if not defined)
%       if ~exist('usemdsplus'); usemdsplus=0; end
%

global usemdsplus
if isempty(usemdsplus); usemdsplus=1; end

error=1;

time_int=[];
if nargin>=4 & ~isempty(varargin{1})
  time_int=varargin{1};
end

if usemdsplus

  % use mdsplus
  
  if ~unix('test -d /home/duval/mdsplus')
    addpath('/home/duval/mdsplus')
  end
  
  if ~unix('test -d /home/osauter/gdat')
    mdsconnect('localhost:8001');
  else
    mdsconnect('localhost');
  end

  user=getenv('USER');
  if nargin>=4 & ~isempty(varargin{1})
    ['[data,error]=mdsvalue(''_rdaeff' user diagname '=augsignal(' num2str(shot) ',"' diagname '","' sigtype '",,,' ...
          num2str(varargin{1}(1),'%.14f') ',' num2str(varargin{1}(end),'%.14f') ')'');']
    eval(['[data,error]=mdsvalue(''_rdaeff' user diagname '=augsignal(' num2str(shot) ',"' diagname '","' sigtype '",,,' ...
          num2str(varargin{1}(1),'%.14f') ',' num2str(varargin{1}(end),'%.14f') ')'');']);
  else
    eval(['[data,error]=mdsvalue(''_rdaeff' user diagname '=augsignal(' num2str(shot) ',"' diagname '","' sigtype '")'');']);
  end
  adata.data=data;
  hsig=[];
  ss=size(data);
  nbofdim=length(ss);
  if ss(end)==1; nbofdim=nbofdim-1; end
  nbofdim=max(nbofdim,1);
  switch nbofdim
  case 1
    eval(['time=mdsvalue(''dim_of(_rdaeff' user diagname ',0)'');']);
    x=[];

  case 2
    eval(['x=mdsvalue(''dim_of(_rdaeff' user diagname ',0)'');']);
    eval(['time=mdsvalue(''dim_of(_rdaeff' user diagname ',1)'');']);

  case 3
    eval(['x=mdsvalue(''dim_of(_rdaeff' user diagname ',0)'');']);
    eval(['time=mdsvalue(''dim_of(_rdaeff' user diagname ',1)'');']);
    disp('3rd dimension in hsig!!!!!!!!!!!!!!!!!!!!!!!!!')
    eval(['hsig=mdsvalue(''dim_of(_rdaeff' user diagname ',2)'');']);

  otherwise
    disp([' more than 3 dimensions for ' num2str(shot) ' ; ' sigtype '/' diagname])
    error('in rdaAUG_eff')
    
  end
  adata.t=time;
  adata.x=x;
  adata.hsig=hsig;
  mdsdisconnect;
  if ~unix('test -d /home/duval/mdsplus')
    rmpath('/home/duval/mdsplus')
  end

else
  % use SF2ML
  if isempty(time_int)
    adata=SF2ML(sigtype,diagname,shot);
  else
    adata=SF2ML(sigtype,diagname,shot,time_int(1),time_int(end));
  end
  if size(adata.y,1)==1
    adata.x=[];
    adata.y=adata.y';
  else
    adata.x=[1:size(adata.y,1)];
  end
  adata.data=adata.y;
  adata.t=adata.t';
%  % transpose data as output in C format, reversed from Fortran and matlab standard
%  ss=size(a);
%  nbofdim=length(ss);
%  if ss(end)==1; nbofdim=nbofdim-1; end
%  nbofdim=max(nbofdim,1);
%  if nbofdim==1
%    data=a;
%  else
%    data=a';
%  end
end

error=0;
